Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(533)

Unified Diff: net/http/http_server_properties_impl.h

Issue 9802003: SPDY - persist SPDY settings. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/http/http_server_properties.h ('k') | net/http/http_server_properties_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/http/http_server_properties_impl.h
===================================================================
--- net/http/http_server_properties_impl.h (revision 128731)
+++ net/http/http_server_properties_impl.h (working copy)
@@ -103,25 +103,22 @@
// Returns all Alternate-Protocol mappings.
virtual const AlternateProtocolMap& alternate_protocol_map() const OVERRIDE;
- // Gets a reference to the SpdySettings stored for a host.
- // If no settings are stored, returns an empty set of settings.
- virtual const SpdySettings& GetSpdySettings(
+ // Gets a reference to the SettingsMap stored for a host.
+ // If no settings are stored, returns an empty SettingsMap.
+ virtual const SettingsMap& GetSpdySettings(
const HostPortPair& host_port_pair) const OVERRIDE;
- // Saves settings for a host. Returns true if SpdySettings are to be
- // persisted because |spdy_settings_map_| has been updated.
- virtual bool SetSpdySettings(const HostPortPair& host_port_pair,
- const SpdySettings& settings) OVERRIDE;
-
- // Saves an individual setting for a host. Returns true if SpdySetting is to
- // be persisted because |spdy_settings_map_| has been updated.
+ // Saves an individual SPDY setting for a host. Returns true if SPDY setting
+ // is to be persisted.
virtual bool SetSpdySetting(const HostPortPair& host_port_pair,
- const SpdySetting& setting) OVERRIDE;
+ SpdySettingsIds id,
+ SpdySettingsFlags flags,
+ uint32 value) OVERRIDE;
- // Clears all spdy_settings.
+ // Clears all entries in |spdy_settings_map_|.
virtual void ClearSpdySettings() OVERRIDE;
- // Returns all persistent SpdySettings.
+ // Returns all persistent SPDY settings.
virtual const SpdySettingsMap& spdy_settings_map() const OVERRIDE;
virtual HttpPipelinedHostCapability GetPipelineCapability(
« no previous file with comments | « net/http/http_server_properties.h ('k') | net/http/http_server_properties_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698